@@ -8,7 +8,6 @@ import llvm.core
 
 from numba.llvm_types import _int1, _int32, _LLVMCaster
 from numba.multiarray_api import MultiarrayAPI # not used
-from numba.symtab import Variable
 from numba import typesystem
 
 from numba import *
@@ -21,11 +20,10 @@ from numba.codegen.llvmcontext import LLVMContextManager
 
 from numba import visitors, nodes, llvm_types, utils, function_util
 from numba.minivect import minitypes, llvm_codegen
-from numba import ndarray_helpers, error, extension_types
-from numba.typesystem import is_obj, promote_to_native
+from numba import ndarray_helpers, error
+from numba.typesystem import is_obj
 from numba.utils import dump
-from numba import naming, metadata
-from numba.functions import keep_alive
+from numba import metadata
 from numba.control_flow import ssa
 from numba.support.numpy_support import sliceutils
 from numba.nodes import constnodes
@@ -184,7 +182,7 @@ class LLVMCodeGenerator(visitors.NumbaVisitor,
             variable = self.symtab.get(argname, None)
 
             if self.renameable(variable):
-                if argtype.is_struct:
+                if argtype.is_struct or argtype.is_reference:
                     larg = self._allocate_arg_local(argname, argtype, larg)
 
                 # Set value on first definition of the variable
@@ -789,10 +787,12 @@ class LLVMCodeGenerator(visitors.NumbaVisitor,
 
         self.builder.position_at_end(then_block)
         then_value = self.visit(node.body)
+        then_block = self.builder.basic_block
         self.builder.branch(merge_block)
 
         self.builder.position_at_end(else_block)
         else_value = self.visit(node.orelse)
+        else_block = self.builder.basic_block
         self.builder.branch(merge_block)
 
         self.builder.position_at_end(merge_block)
@@ -871,7 +871,6 @@ class LLVMCodeGenerator(visitors.NumbaVisitor,
 
     def visit_Return(self, node):
         if node.value is not None:
-            value_type = node.value.type
             rettype = self.func_signature.return_type
 
             retval = self.visit(node.value)
@@ -920,7 +919,11 @@ class LLVMCodeGenerator(visitors.NumbaVisitor,
         index = self.visit(node.slice)
         indices = [index]
 
-        lptr = self.builder.gep(value, indices)
+        if value.type.kind == llvm.core.TYPE_ARRAY:
+            lptr = self.builder.extract_value(value, index)
+        else:
+            lptr = self.builder.gep(value, indices)
+
         if node.slice.type.is_int:
             lptr = self._handle_ctx(node, lptr, node.value.type)
 
