@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
 from numba import *
 from .minivect import minitypes
 from . import llvm_types
