@@ -21,6 +21,7 @@ from numba import control_flow
 from numba import optimize
 from numba import closures
 from numba import reporting
+from numba import normalize
 from numba.codegen import llvmwrapper
 from numba import ast_constant_folding as constant_folding
 from numba.control_flow import ssa
@@ -31,7 +32,13 @@ from numba.type_inference import infer as type_inference
 from numba.asdl import schema
 from numba.minivect import minitypes
 import numba.visitors
-from numba.specialize import comparisons, loops, exceptions, funccalls
+
+from numba.specialize import comparisons
+from numba.specialize import loops
+from numba.specialize import exceptions
+from numba.specialize import funccalls
+from numba.specialize import exttypes
+
 from numba import astsix
 
 logger = logging.getLogger(__name__)
@@ -183,9 +190,7 @@ class PipelineStage(object):
                     flags, parent_func_env = env.translation.stack[-2]
                     error_env.merge_in(parent_func_env.error_env)
                 else:
-                    reporting.report(error_env,
-                                     error_env.enable_post_mortem,
-                                     exc=e)
+                    reporting.report(env, exc=e)
                 raise
 
         env.translation.crnt.ast = ast
@@ -238,7 +243,8 @@ def validate_signature(tree, env):
     if (isinstance(tree, ast_module.FunctionDef) and
         len(arg_types) != len(tree.args.args)):
         raise error.NumbaError(
-            "Incorrect number of types specified in @jit()")
+            "Incorrect number of types specified in @jit() for function %r" %
+            env.crnt.func_name)
 
     return tree
 
@@ -300,6 +306,12 @@ def create_lfunc3(tree, env):
     create_lfunc(tree, env)
     return tree
 
+
+class NormalizeASTStage(PipelineStage):
+    def transform(self, ast, env):
+        transform = self.make_specializer(normalize.NormalizeAST, ast, env)
+        return transform.visit(ast)
+
 class ControlFlowAnalysis(PipelineStage):
     _pre_condition_schema = None
 
@@ -446,6 +458,11 @@ class LateSpecializer(PipelineStage):
                                             env)
         return specializer.visit(ast)
 
+class ExtensionTypeLowerer(PipelineStage):
+    def transform(self, ast, env):
+        specializer = self.make_specializer(exttypes.ExtensionTypeLowerer,
+                                            ast, env)
+        return specializer.visit(ast)
 
 class SpecializeFunccalls(PipelineStage):
     def transform(self, ast, env):
@@ -528,16 +545,15 @@ class WrapperStage(PipelineStage):
             func_env.numba_wrapper_func = numbawrapper
             func_env.llvm_wrapper_func = lfuncwrapper
 
+            # Set pointer to function for external code and numba.addressof()
+            numbawrapper.lfunc_pointer = func_env.lfunc_pointer
+
         return ast
 
 class ErrorReporting(PipelineStage):
     "Sort and issue warnings and errors"
     def transform(self, ast, env):
-        func_env = env.translation.crnt
-        error_env = func_env.error_env
-        post_mortem = error_env.enable_post_mortem
-        reporting.report(error_env,
-                         post_mortem=post_mortem)
+        reporting.report(env)
         return ast
 
 class ComposedPipelineStage(PipelineStage):
@@ -552,7 +568,7 @@ class ComposedPipelineStage(PipelineStage):
     @staticmethod
     def check_stage(stage):
         def _check_stage_object(stage_obj):
-            if (isinstance(stage_obj, (type, types.ClassType)) and
+            if (isinstance(stage_obj, type) and
                     issubclass(stage_obj, PipelineStage)):
                 stage_obj = stage_obj()
             return stage_obj
