@@ -45,4 +45,4 @@ def pow2_const():
 if __name__ == '__main__':
 #    import logging; logging.getLogger().setLevel(0)
     import numba
-    numba.testmod()
+    numba.testing.testmod()
