@@ -1,5 +1,5 @@
 import numba; from numba import *; from numba.error import NumbaError
-from numba.tests.test_support import rewrite_doc
+from numba.testing.test_support import rewrite_doc
 @autojit
 def error1():
     def inner():
@@ -35,7 +35,7 @@ def error5():
 
     inner(10, a=20, b=30)
 
-@autojit
+@autojit(warnstyle='simple')
 def closure1():
     a = 10
     @jit(restype=void, argtypes=[int_])
@@ -421,4 +421,4 @@ if __name__ == '__main__':
 #    test_call_closure_from_closure()()
     # wrong_restype()
     import numba
-    numba.testmod()
+    numba.testing.testmod()
