@@ -1,3 +1,6 @@
+# -*- coding: utf-8 -*-
+from __future__ import print_function, division, absolute_import
+
 import numpy as np
 
 from numba import autojit, register_callable, npy_intp, typesystem
