@@ -5,7 +5,7 @@ from numba import *
 from numba import c_string_type as cstring, int_
 
 from nose.tools import nottest
-from numba.tests import test_support
+from numba.testing import test_support
 
 # ______________________________________________________________________
 
