@@ -515,8 +515,8 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
         if dest is not None:
             raise error.NumbaError(dest, "No file may be given in nopython mode")
 
-        stdin, stdout, stderr = stdio_util.get_stdio_streams()
-        stdout = stdio_util.get_stream_as_node(stdout)
+        # stdin, stdout, stderr = stdio_util.get_stdio_streams()
+        # stdout = stdio_util.get_stream_as_node(stdout)
 
         format = codegen.get_printf_specifier(value.type)
         if format is None:
@@ -610,21 +610,14 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
         self.generic_visit(node)
         return nodes.ObjectTempNode(node)
 
-    def visit_NativeFunctionCallNode(self, node):
-        if node.signature.is_bound_method:
-            assert isinstance(node.function, nodes.ExtensionMethod)
-            return self.visit_ExtensionMethod(node.function, node)
-
-        self.visitchildren(node)
-        return node
-
     def visit_ObjectCallNode(self, node):
         # self.generic_visit(node)
         assert node.function
 
         if self.nopython:
+            meth_name = node.name and ' (%r)' % node.name
             raise error.NumbaError(node, "Cannot use object call in "
-                                         "nopython context")
+                                         "nopython context" + meth_name)
 
         node.function = self.visit(node.function)
         node.args_tuple = self.visit(node.args_tuple)
@@ -834,69 +827,6 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
         self.generic_visit(node)
         return node
 
-    def visit_ExtTypeAttribute(self, node):
-        """
-        Resolve an extension attribute:
-
-            ((attributes_struct *)
-                 (((char *) obj) + attributes_offset))->attribute
-        """
-        ext_type = node.value.type
-        offset = ext_type.attr_offset
-        type = ext_type.attribute_struct
-
-        if isinstance(node.ctx, ast.Load):
-            value_type = type.ref()         # Load result
-        else:
-            value_type = type.pointer()     # Use pointer for storage
-
-        struct_pointer = nodes.value_at_offset(node.value, offset,
-                                               value_type)
-        result = nodes.StructAttribute(struct_pointer, node.attr,
-                                       node.ctx, type.ref())
-
-        return self.visit(result)
-
-    def visit_ExtensionMethod(self, node, call_node=None):
-        """
-        Resolve an extension method:
-
-            typedef {
-                double (*method1)(double);
-                ...
-            } vtab_struct;
-
-            vtab_struct *vtab = *(vtab_struct **) (((char *) obj) + vtab_offset)
-            void *method = vtab[index]
-        """
-        if call_node is None:
-            raise error.NumbaError(node, "Referenced extension method '%s' "
-                                         "must be called" % node.attr)
-
-        # Make the object we call the method on clone-able
-        node.value = nodes.CloneableNode(self.visit(node.value))
-
-        ext_type = node.value.type
-        offset = ext_type.vtab_offset
-        struct_type = ext_type.vtab_type.ref()
-
-        struct_pointer_pointer = nodes.value_at_offset(node.value, offset,
-                                                       struct_type.pointer())
-        struct_pointer = nodes.DereferenceNode(struct_pointer_pointer)
-
-        vmethod = nodes.StructAttribute(struct_pointer, node.attr,
-                                        ast.Load(), struct_type)
-
-        # Visit argument list for call
-        args = self.visitlist(call_node.args)
-
-        # Insert first argument 'self' in args list
-        args.insert(0, nodes.CloneNode(node.value))
-        result = nodes.NativeFunctionCallNode(node.type, vmethod, args)
-        result.signature.is_bound_method = False
-
-        return self.visit(result)
-
     def visit_ArrayNewNode(self, node):
         if self.nopython:
             # Give the codegen (subclass) a chance to handle this
@@ -921,7 +851,8 @@ class LateSpecializer(ResolveCoercions, LateBuiltinResolverMixin,
             incref_base = nodes.IncrefNode(base)
             args.append(base.clone)
 
-        array = nodes.PyArray_NewFromDescr(args).cloneable
+        array = nodes.PyArray_NewFromDescr(args)
+        array = nodes.ObjectTempNode(array).cloneable
         body = [incref_descr, incref_base, array, setbase]
 
         if node.base is not None:
